﻿using Microsoft.Xna.Framework;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Model
{
    /// <summary>
    /// This class holds states in the scope of the entire gameplay
    /// </summary>
    static class GameState
    {
        public static readonly int SCREEN_HEIGHT = 640;
        public static readonly int SCREEN_WIDTH = 960;
        /**
        Sets and gets if a playable unit is selected
        */
        public static bool playableUnitSelected { get; set; }
        /**
        Sets and gets a unit
        */
        public static Unit selectedUnit { get; set; }
        /**
        Sets and gets the unit to attack
        */
        public static Unit unitToAttack { get; set; }
        /**
        Sets and gets the current player
        */
        public static Player currentPlayer { get; set; }
        /**
        Sets and gets the enemy player
        */
        public static Player enemyPlayer { get; set; }
        /**
        Sets and gets whether drop down menu should be open
        */
        public static bool dropDownMenuOpen { get; set; }
        /**
        Sets and gets whether attackConfirm menu should be open
        */
        public static bool attackConfirmOpen { get; set; }
        /**
        Sets and gets whether player is currently selecting unit to attack
        */
        public static bool attackSelect { get; set; }
        /**
        Sets and gets whether inventory menu should be open
        */
        public static bool inventoryOpen { get; set; }
        /**
        Sets and gets whether end turn button is active
        **/
        public static bool endTurnButton { get; set; }
        /**
        Sets and gets if a unit has moved yet or not. beforeMOve is true before unit moves, false after it moves. Used to determine what tiles are highlighted
        */
        public static bool beforeMove { get; set; }
        /*
        Sets and gets whether an animation sequence is currently on screen
        */
        public static bool isAnimating { get; set; }
        /**
        Sets and gets whether game is over
        */
        public static bool gameOver { get; set; }
        /**
        Sets and gets if game should exit
        */
        public static bool exitGameClicked { get; set; }
        /**
        Sets and gets end turn button position
        */
        public static Vector2 endTurnButtonLocation { get; set; }
        /**
        sets and gets whether it is currently transitioning turns
        */
        public static bool transitionTurn { get; set; }
        /*
        Sets and gets movable nodes that can be retrieved without calling path finding
        */
        public static LinkedList<Node> moveableNodes { get; set; }
    }
    /*
    enumerated list for different possible Game States
    */
    enum GameMenuState
    {
        MainMenu,       // menu screen
        HowToPlay,      // Instruction Screen 1
        HowToPlay2,     // Instruction Screen 2
        HowToPlay3,     // Instructions Screen 3
        Playing,        // Playing game Screen
        DropDownMenu,   // Drop down menu for action
        CharMenu,       // character drop down info menu
        AttackMenu,     // attack menu
        GameOver        // Game is Over
    }
    /*
    enumerated list for what the current turn state is (per unit)
    */
    enum TurnState
    {
        Wait,
        AttackMenu,
        Attack,
        Move,
        Items
    }
}
